<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * @package mod
 * @subpackage dataplus
 * @copyright 2011 The Open University
 * @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

require_once($CFG->dirroot . '/mod/dataplus/backup/moodle2/restore_dataplus_stepslib.php');
/**
 * DataPlus restore task that provides all the settings and steps to perform one
 * complete restore of the activity
 */
class restore_dataplus_activity_task extends restore_activity_task {

    /**
     * Define (add) particular settings this activity can have
     */
    protected function define_my_settings() {
        // No particular settings for this activity
    }

    /**
     * Define (add) particular steps this activity can have
     */
    protected function define_my_steps() {
        // Choice only has one structure step
        $xml = 'dataplus.xml';
        $this->add_step(new restore_dataplus_activity_structure_step('dataplus_structure', $xml));
    }

    /**
     * Define the contents in the activity that must be
     * processed by the link decoder
     */
    static public function define_decode_contents() {
        $contents = array();

        $contents[] = new restore_decode_content('dataplus', array('intro'), 'dataplus');

        return $contents;
    }

    /**
     * Define the decoding rules for links belonging
     * to the activity to be executed by the link decoder
     */
    static public function define_decode_rules() {
        $rules = array();

        return $rules;

    }

    /**
     * Define the restore log rules that will be applied
     * by the {@link restore_logs_processor} when restoring
     * DataPlus logs. It must return one array
     * of {@link restore_log_rule} objects
     */
    static public function define_restore_log_rules() {
        $details = array('createcolumn' => 'manage.php?id={course_module}',
                         'editcolumn' => 'manage.php?id={course_module}',
                         'deletecolumn' => 'manage.php?id={course_module}',
                         'view' => 'view.php?id={course_module}',
                         'update' => 'view.php?id={course_module}',
                         'insert' => 'view.php?id={course_module}',
                         'delete' => 'view.php?id={course_module}',
                         'search' => 'view.php?id={course_module}',
                         'update comment' => 'view.php?id={course_module}',
                         'insert comment' => 'view.php?id={course_module}',
                         'delete comment' => 'view.php?id={course_module}');

        $rules = array();

        foreach ($details as $detail => $url) {
            $rules[] = new restore_log_rule('dataplus', $detail, $url, '{dataplus}');
        }

        return $rules;
    }

    /**
     * Define the restore log rules that will be applied
     * by the {@link restore_logs_processor} when restoring
     * course logs. It must return one array
     * of {@link restore_log_rule} objects
     *
     * Note this rules are applied when restoring course logs
     * by the restore final task, but are defined here at
     * activity level. All them are rules not linked to any module instance (cmid = 0)
     */
    static public function define_restore_log_rules_for_course() {
        $rules = array();

        return $rules;
    }
}